@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -8,16 +8,16 @@
 //
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
-//
 
 package rest
 
 import (
-	"github.com/eclipse/che-machine-exec/auth"
-	"github.com/eclipse/che-machine-exec/common/rest"
 	"net/http"
 
-	"github.com/eclipse/che-machine-exec/api/model"
+	"github.com/eclipse-che/che-machine-exec/auth"
+	"github.com/eclipse-che/che-machine-exec/common/rest"
+
+	"github.com/eclipse-che/che-machine-exec/api/model"
 	"github.com/gin-gonic/gin"
 	"github.com/sirupsen/logrus"
 )
@@ -39,6 +39,9 @@ func HandleKubeConfig(c *gin.Context) {
 		return
 	}
 
+	kubeConfigParams := initConfigParams.KubeConfigParams
+	kubeConfigParams.BearerToken = token
+
 	if initConfigParams.ContainerName == "" {
 		c.Writer.WriteHeader(http.StatusBadRequest)
 		_, err := c.Writer.Write([]byte("Container name is required"))
@@ -48,7 +51,13 @@ func HandleKubeConfig(c *gin.Context) {
 		return
 	}
 
-	err := HandleKubeConfigCreation(c, &initConfigParams, token)
+	execRequest := handleContainerResolve(c, token, initConfigParams.ContainerName)
+	if execRequest == nil {
+		rest.WriteResponse(c, http.StatusInternalServerError, "Could not retrieve exec request")
+		return
+	}
+
+	err := HandleKubeConfigCreation(&kubeConfigParams, &execRequest.ContainerInfo)
 
 	if err != nil {
 		logrus.Errorf("Unable to create kubeconfig. Cause: %s", err.Error())
