@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -8,13 +8,12 @@
 //
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
-//
 
 package exec_info
 
 import (
-	"github.com/eclipse/che-machine-exec/api/model"
-	"k8s.io/client-go/kubernetes/typed/core/v1"
+	"github.com/eclipse-che/che-machine-exec/api/model"
+	v1 "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/rest"
 )
 
